pytilities.types.numerictype

Package pytilities :: Package types :: Module numerictype |
[hide private]
[frames] | no frames]

# Source Code for Module pytilities.types.numerictype

     1  # Copyright (C) 2010 Tim Diels <limyreth@users.sourceforge.net>
     2  #
     3  # This file is part of pytilities.
     4  #
     5  # pytilities is free software: you can redistribute it and/or modify
     6  # it under the terms of the GNU General Public License as published by
     7  # the Free Software Foundation, either version 3 of the License, or
     8  # (at your option) any later version.
     9  #
    10  # pytilities is distributed in the hope that it will be useful,
    11  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    12  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    13  # GNU General Public License for more details.
    14  #
    15  # You should have received a copy of the GNU General Public License
    16  # along with pytilities.  If not, see <http://www.gnu.org/licenses/>.
    17  #
    18
    19  __docformat__ = 'reStructuredText'
    20
    21  from . import _NumericTypeMeta
    22
    23 -class NumericType(object):
    24      """
    25      Represents any numeric type.
    26
    27      Numeric strings, ints (, longs) and floats are indirect instances of this
    28      class. Ints (, longs) and floats are subclasses of this class. Note that a
    29      string is not a subclass (some strings are numeric, but not all, and there
    30      is no numeric string type).
    31      """
    32      __metaclass__ = _NumericTypeMeta
    33